@@ -97,7 +97,7 @@ public class Config {
     /**
      * the location of the log
      */
-    public String ENGINE_LOGFILE = "/var/log/open-xchange/readerengine.log";
+    public String ENGINE_LOGFILE = null;
 
     /**
      * determines the amount and detail of logging data; 3 = errors, 2 = errors and warnings, 1 = errors and warnings and infos, 0 =
@@ -158,13 +158,13 @@ public class Config {
      */
     public boolean ENGINE_DEBUG = false;
 
+    /**
+     * internal switch for debugging
+     */
+    public int ENGINE_TEST_PERFORMANCE_RUN_COUNT = 1;
+
     /**
      * the logger to be used for logging
      */
     public org.slf4j.Logger logger = null;
-
-    /**
-     * the location of the performance directory
-     */
-    public String ENGINE_PERFORMANCEDIR = null;
 }
