@@ -55,7 +55,12 @@ public interface ICache {
      * @param hash The hash value to search for within the cache.
      * @return The entry with the given hash value or null if no such object exists within the cache.
      */
-    public ICacheEntry acquireEntry(String hash);
+    /**
+     * @param hash The hash value to search for within the cache
+     * @param args String parameters, whose usage is depending on the implementation
+     * @return
+     */
+    public ICacheEntry acquireEntry(String hash, String... args);
 
     /**
      * Releases an entry and all connected resources from a previous call to <code>acquireEntry</code>.
