@@ -28,7 +28,8 @@ public interface IJobStatusListener {
      * notifies a registered JobStatusListener that the status of a Job has just changed; the current status of the Job can be retrieved
      * from the JobProcessor via the given Job id string
      *
-     * @param jobIdStr
+     * @param jobIdStr the ID string of the currently changed job
+     * @param data Internal data
      */
-    public void statusChanged(String jobIdStr);
+    public void statusChanged(String jobIdStr, Object data);
 }
