@@ -66,6 +66,8 @@ public class Properties {
 
     static final public String PROP_INPUTFILE_HASH = "InputFileHash"; // String
 
+    static final public String PROP_LOCALE = "Locale"; // String
+
     static final public String PROP_CACHE_PROPERTIES_FILENAME = "properties"; // String
 
     static final public String PROP_CACHE_RESULT_FILENAME = "result"; // String
@@ -112,12 +114,18 @@ public class Properties {
 
     static final public String PROP_INFO_FILENAME = INFO_PREFIX + "Filename"; // String
 
+    static final public String PROP_FEATURES_ID = "FeaturesId"; // Integer
+
+    static final public String PROP_CONVERTER_COOKIE = "ConverterCookie"; // String
+
     // -------------------------------------------------------------------------
 
     static final public String PROP_RESULT_CACHE_HASH = PROP_CACHE_HASH; // String
 
     static final public String PROP_RESULT_INPUTFILE_HASH = PROP_INPUTFILE_HASH; // String
 
+    static final public String PROP_RESULT_LOCALE = PROP_LOCALE; // String
+
     static final public String PROP_RESULT_ERROR_CODE = "ErrorCode"; // Integer
 
     static final public String PROP_RESULT_EXTENSION = "Extension"; // String
@@ -136,12 +144,18 @@ public class Properties {
 
     static final public String PROP_RESULT_PASSWORD_PROTECTED = "PasswordProtected"; // Boolean
 
+    static final public String PROP_RESULT_NO_DOCUMENT_CONTENT = "NoDocumentContent"; // Boolean
+
     static final public String PROP_RESULT_TEMP_INPUT_FILE = "TempInputFile"; // File
 
     static final public String PROP_RESULT_SINGLE_PAGE_JOBTYPE = "SinglePageJobType"; // String
 
     static final public String PROP_RESULT_ZIP_ARCHIVE = PROP_ZIP_ARCHIVE; // Boolean
 
+    static final public String PROP_RESULT_CACHE_REMOTEURL = "CacheRemoteUrl"; // String
+
+    static final public String PROP_RESULT_CONVERTER_COOKIE = PROP_CONVERTER_COOKIE; // String
+
     // -------------------------------------------------------------------------
 
     static public final String OX_RESCUEDOCUMENT_EXTENSION_APPENDIX = "_ox";
